{% extends "registration/base.html" %}

{% load i18n %}

{% block content %}
  <p class="login-box-msg">{{ richmin_settings.welcome_sign }}</p>
  <p class="text-center">
    {% trans "Thanks for spending some quality time with the Web site today." %}
  </p>
  <a class="btn {{ richmin_ui.button_classes.primary }} btn-block" href="{% url 'admin:index' %}">
    {% trans 'Log in again' %}
  </a>
{% endblock %}
